==> phpAdsNew_1.6.2.tar.gz: phpAdsNew_1.6.2/spanish.inc.php <==
<?

$strHome = "Home";
$date_format = "%m/%d/%Y";
$time_format = "%H:%i:%S";
$strMySQLError = "MySQL-Error:";
$strAdminstration = "Administraci&oacute;n";
$strAddClient = "Adicionar un nuevo cliente";
$strModifyClient = "Modificar cliente";
$strDeleteClient = "Borrar cliente";
$strViewClientStats = "Ver estadisticas del cliente";
$strClientName = "Cliente";
$strContact = "Contacto";
$strEMail = "EMail";
$strViews = "Ad Vistas";
$strClicks = "Ad Clicks";
$strTotalViews = "Total Ad Vistas";
$strTotalClicks = "Total Ad Clicks";
$strCTR = "Click-Throuh Ratio";
$strTotalClients = "Total clients";
$strActiveClients = "Active clients";
$strActiveBanners = "Active banners";
$strLogout = "Logout";
$strCreditStats = "Credit Stats";
$strViewCredits = "Adview credits";   
$strClickCredits = "Adclick credits";
$strPrevious = "Previous";
$strNext = "Next";
$strNone = "None";
$strViewsPurchased = "Ad Vistas comprados";
$strClicksPurchased = "Ad Clicks comprados";
$strDaysPurchased = "AdDays purchased";
$strHTML = "HTML";
$strAddSep = "Complete en cualquiera de los campos de arriba o los campos de abajo!";
$strTextBelow = "Texto debajo de la imagen";
$strSubmit = "Enviar ad";
$strUsername = "Nombre de Usuario";
$strPassword = "Clave de Acceso";
$strBannerAdmin = "Administracion de Banner para";
$strBannerAdminAcl = "Banner ACL adminstration for";
$strNoBanners = "No se encontraron banners";
$strBanner = "Banner";
$strCurrentBanner = "Banner Actual";
$strDelete = "Borrar";
$strAddBanner  = "Adicionar nuevo banner";
$strModifyBanner  = "Modificar banner";
$strModifyBannerAcl  = "Modify banner ACL";
$strURL = "Enlace a URL (incl. http://)";
$strKeyword = "Palabra Clave";
$strWeight = "Weight";
$strAlt = "Texto-Alterno";
$strAccessDenied = "Access Denegado";
$strNotAdmin = "Usted no tiene privilegios de Administraci&oacute;n";
$strClientAdded = "El Cliente ha sido adicionado.";
$strClientModified = "El Cliente ha sido modificado.";
$strClientDeleted = "El Cliente ha sido borrado.";
$strBannerAdmin = "Administraci&oacute;n de Banners";
$strBannerAdded = "El Banner ha sido adicionado.";
$strBannerModified = "El Banner ha sido modificado.";
$strBannerDeleted = "El Banner ha sido borrado";
$strBannerChanged = "El Banner ha sido cambiado";
$strStats = "Estadisticas";
$strDailyStats = "Estadisticas Diarias";
$strDetailStats = "Estadisticas Detalladas";
$strCreditStats = "Credit statistics";
$strActive = "activo";
$strActivate = "Activar";
$strDeActivate = "Desactivar";
$strAuthentification = "Autenticaci&oacute;n";
$strGo = "Ver";
$strLinkedTo = "enlace a";
$strBannerID = "Banner-ID";
$strClientID = "Cliente ID";
$strMailSubject ="Reporte de Publicidad";
$strMailSubjectDeleted = "Deactivated Ads";
$strMailHeader = 'Estimado ".$clients[$i][contact].",\n';
$strMailBannerStats = 'seguidamente usted encontrar&oacute; las estadisticas de banner para ".$clients[$i][clientname].":';
$strMailFooter = 'Atte,\n   $phpAds_admin_fullname';
$strMailNothingLeft = 'usted no tiene Ad Vistas disponibles en su cuenta con nosotros. Por lo tanto, sus banner han sido desactivados.\n\nSi usted quiere adquirir ad views adicionales, por favor no dude en contactarnos. Estaremos encantdos de escudharlo.';
$strLogMailSent = "[phpAds] Estadisticas enviadas satisfactoriamente.";
$strLogErrorClients = "[phpAds] Ocurrio un error mientras intentaba cargar los clientes de la Base de Datos.";
$strLogErrorBanners = "[phpAds] Ocurrio un error mientras intentaba cargar los banner de la Base de Datos.";
$strLogErrorViews = "[phpAds] Ocurrio un error mientras intentaba cargar los ad vistas de la Base de Datos.";
$strLogErrorClicks = "[phpAds] Ocurrio un error mientras intentaba cargar los ad clicks de la Base de Datos.";
$strLogErrorDisactivate = "[phpAds] Ocurrio un error mientras intentaba desactivar un banner.";
$strRatio = "Porcentaje de Click's";
$strChooseBanner = "Por favor escoja el tipo de banner.";
$strMySQLBanner = "Banner almacenado en MySQL";
$strURLBanner = "Banner remitido a traves de un URL";
$strHTMLBanner = "HTML banner";
$strNewBannerFile = "Nuevo archivo de Banner";
$strNewBannerURL = "Nuevo URL de banner (incl. http://)";
$strWidth = "Ancho";
$strHeight = "Largo";
$strTotalViews7Days = "Total Ad Vistas en los ultimos 7 dias";
$strTotalClicks7Days = "Total Ad Clicks en los ultimos 7 dias";
$strAvgViews7Days = "Promedio de Ad Vistas en los ultimos 7 dias";
$strAvgClicks7Days = "Promedio de Ad Clicks en los ultimos 7 dias";
$strTopTenHosts = "Top ten solicitud sitios";
$strConfirmDeleteClient = "Esta seguro de borrar este cliente?";
$strClientIP = "Client IP";
$strUserAgent = "User agent regexp";
$strWeekDay = "Week day (0 - 6)";
$strDomain = "Domain (excluding dot)";
$strSource = "Source";
$strTime = "Time";
$strAllow = "Allow";
$strDeny = "Deny";
$strResetStats = "Reset Statistics";
?>

==> phpAdsNew_1.8.0.tar.gz: phpAdsNew_1.8.0/spanish.inc.php <==
<?

$strHome = "Home";
$date_format = "%m/%d/%Y";
$time_format = "%H:%i:%S";
$strMySQLError = "MySQL-Error:";
$strAdminstration = "Administraci&oacute;n";
$strAddClient = "Adicionar un nuevo cliente";
$strModifyClient = "Modificar cliente";
$strDeleteClient = "Borrar cliente";
$strViewClientStats = "Ver estadisticas del cliente";
$strClientName = "Cliente";
$strContact = "Contacto";
$strEMail = "EMail";
$strViews = "Ad Vistas";
$strClicks = "Ad Clicks";
$strTotalViews = "Total Ad Vistas";
$strTotalClicks = "Total Ad Clicks";
$strCTR = "Click-Through Ratio";
$strTotalClients = "Total clients";
$strActiveClients = "Active clients";
$strActiveBanners = "Active banners";
$strLogout = "Logout";
$strCreditStats = "Credit Stats";
$strViewCredits = "Adview credits";   
$strClickCredits = "Adclick credits";
$strPrevious = "Previous";
$strNext = "Next";
$strNone = "None";
$strViewsPurchased = "Ad Vistas comprados";
$strClicksPurchased = "Ad Clicks comprados";
$strDaysPurchased = "AdDays purchased";
$strHTML = "HTML";
$strAddSep = "Complete en cualquiera de los campos de arriba o los campos de abajo!";
$strTextBelow = "Texto debajo de la imagen";
$strSubmit = "Enviar ad";
$strUsername = "Nombre de Usuario";
$strPassword = "Clave de Acceso";
$strBannerAdmin = "Administracion de Banner para";
$strBannerAdminAcl = "Banner ACL adminstration for";
$strNoBanners = "No se encontraron banners";
$strBanner = "Banner";
$strCurrentBanner = "Banner Actual";
$strDelete = "Borrar";
$strAddBanner  = "Adicionar nuevo banner";
$strModifyBanner  = "Modificar banner";
$strModifyBannerAcl  = "Modify banner ACL";
$strURL = "Enlace a URL (incl. http://)";
$strKeyword = "Palabra Clave";
$strWeight = "Weight";
$strAlt = "Texto-Alterno";
$strAccessDenied = "Access Denegado";
$strNotAdmin = "Usted no tiene privilegios de Administraci&oacute;n";
$strClientAdded = "El Cliente ha sido adicionado.";
$strClientModified = "El Cliente ha sido modificado.";
$strClientDeleted = "El Cliente ha sido borrado.";
$strBannerAdmin = "Administraci&oacute;n de Banners";
$strBannerAdded = "El Banner ha sido adicionado.";
$strBannerModified = "El Banner ha sido modificado.";
$strBannerDeleted = "El Banner ha sido borrado";
$strBannerChanged = "El Banner ha sido cambiado";
$strStats = "Estadisticas";
$strDailyStats = "Estadisticas Diarias";
$strDetailStats = "Estadisticas Detalladas";
$strCreditStats = "Credit statistics";
$strActive = "activo";
$strActivate = "Activar";
$strDeActivate = "Desactivar";
$strAuthentification = "Autenticaci&oacute;n";
$strGo = "Ver";
$strLinkedTo = "enlace a";
$strBannerID = "Banner-ID";
$strClientID = "Cliente ID";
$strMailSubject ="Reporte de Publicidad";
$strMailSubjectDeleted = "Deactivated Ads";
$strMailHeader = 'Estimado ".$clients[$i][contact].",\n';
$strMailBannerStats = 'seguidamente usted encontrar&oacute; las estadisticas de banner para ".$clients[$i][clientname].":';
$strMailFooter = 'Atte,\n   $phpAds_admin_fullname';
$strMailNothingLeft = 'usted no tiene Ad Vistas disponibles en su cuenta con nosotros. Por lo tanto, sus banner han sido desactivados.\n\nSi usted quiere adquirir ad views adicionales, por favor no dude en contactarnos. Estaremos encantdos de escudharlo.';
$strLogMailSent = "[phpAds] Estadisticas enviadas satisfactoriamente.";
$strLogErrorClients = "[phpAds] Ocurrio un error mientras intentaba cargar los clientes de la Base de Datos.";
$strLogErrorBanners = "[phpAds] Ocurrio un error mientras intentaba cargar los banner de la Base de Datos.";
$strLogErrorViews = "[phpAds] Ocurrio un error mientras intentaba cargar los ad vistas de la Base de Datos.";
$strLogErrorClicks = "[phpAds] Ocurrio un error mientras intentaba cargar los ad clicks de la Base de Datos.";
$strLogErrorDisactivate = "[phpAds] Ocurrio un error mientras intentaba desactivar un banner.";
$strRatio = "Porcentaje de Click's";
$strChooseBanner = "Por favor escoja el tipo de banner.";
$strMySQLBanner = "Banner almacenado en MySQL";
$strURLBanner = "Banner remitido a traves de un URL";
$strHTMLBanner = "HTML banner";
$strNewBannerFile = "Nuevo archivo de Banner";
$strNewBannerURL = "Nuevo URL de banner (incl. http://)";
$strWidth = "Ancho";
$strHeight = "Largo";
$strTotalViews7Days = "Total Ad Vistas en los ultimos 7 dias";
$strTotalClicks7Days = "Total Ad Clicks en los ultimos 7 dias";
$strAvgViews7Days = "Promedio de Ad Vistas en los ultimos 7 dias";
$strAvgClicks7Days = "Promedio de Ad Clicks en los ultimos 7 dias";
$strTopTenHosts = "Top ten solicitud sitios";
$strConfirmDeleteClient = "Esta seguro de borrar este cliente?";
$strClientIP = "Client IP";
$strUserAgent = "User agent regexp";
$strWeekDay = "Week day (0 - 6)";
$strDomain = "Domain (excluding dot)";
$strSource = "Source";
$strTime = "Time";
$strAllow = "Allow";
$strDeny = "Deny";
$strResetStats = "Reset Statistics";
$strConfirmResetStats = "Do you really want to reset stats for this client ?";
$strExpiration = "Expiration";
$strDaysLeft = "Days left";
$strEstimated = "Estimated expiration";
$strConfirm = "Are you sure ?";
$strBannerNoStats = "No statistics available for this banner!";
$strWeek = "Week";
$strWeeklyStats = "Weekly statistics";
$strWeekDay = "Weekday";
$strDate = "Date";
$strCTRShort = "CTR";
$strDayShortCuts=array("Su","Mo","Tu","We","Th","Fr","Sa");
$strShowWeeks="Max. weeks to display";
$strAll="all";
$strAvg="Avg.";
$strHourly="Views/Clicks by hour";
$strTotal = "Total";
$strUnlimited = "Unlimited";

?>
